# ModelInstanceNewVersionRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**version_notes** | **str** | The version notes for the model instance version | [optional] 
**files** | [**list[UploadFile]**](UploadFile.md) | A list of files that should be associated with the model instance version | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


